HTML Tag Class
==============

``wdom.dom.Tag`` class provides DOM implementation synchronized both on
python and browser.


Tag class
---------

.. currentmodule:: wdom.tag

.. automodule:: wdom.tag

   .. autoclass:: Tag
      :inherited-members:
      :members:

   .. autofunction:: NewTagClass

   .. autoclass:: RawHtmlNode


List of HTML Tag Classes
------------------------

.. currentmodule:: wdom.tag

.. autoclass:: A
.. autoclass:: Body
.. autoclass:: Br
.. autoclass:: Button
.. autoclass:: Cite
.. autoclass:: Code
.. autoclass:: Dd
.. autoclass:: Div
.. autoclass:: Dl
.. autoclass:: Dt
.. autoclass:: Em
.. autoclass:: Form
.. autoclass:: H1
.. autoclass:: H2
.. autoclass:: H3
.. autoclass:: H4
.. autoclass:: H5
.. autoclass:: H6
.. autoclass:: Head
.. autoclass:: Hr
.. autoclass:: Html
.. autoclass:: Img
.. autoclass:: Input
.. autoclass:: Label
.. autoclass:: Li
.. autoclass:: Link
.. autoclass:: Meta
.. autoclass:: Ol
.. autoclass:: Option
.. autoclass:: P
.. autoclass:: Pre
.. autoclass:: Script
.. autoclass:: Select
.. autoclass:: Span
.. autoclass:: Strong
.. autoclass:: Style
.. autoclass:: Table
.. autoclass:: Tbody
.. autoclass:: Td
.. autoclass:: Textarea
.. autoclass:: Tfoot
.. autoclass:: Th
.. autoclass:: Thead
.. autoclass:: Title
.. autoclass:: Tr
.. autoclass:: U
.. autoclass:: Ul


..
    Extended HTML Tag Classes
    ^^^^^^^^^^^^^^^^^^^^^^^^^
    .. autoclass:: Col
    .. autoclass:: Col1
    .. autoclass:: Col2
    .. autoclass:: Col3
    .. autoclass:: Col4
    .. autoclass:: Col5
    .. autoclass:: Col6
    .. autoclass:: Col7
    .. autoclass:: Col8
    .. autoclass:: Col9
    .. autoclass:: Col10
    .. autoclass:: Col11
    .. autoclass:: Col12
    .. autoclass:: Container
    .. autoclass:: DangerButton
    .. autoclass:: DefaultButton
    .. autoclass:: ErrorButton
    .. autoclass:: FormGroup
    .. autoclass:: InfoButton
    .. autoclass:: LinkButton
    .. autoclass:: PrimaryButton
    .. autoclass:: Row
    .. autoclass:: SecondaryButton
    .. autoclass:: SuccessButton
    .. autoclass:: WarningButton
    .. autoclass:: Wrapper

